@@ -8,7 +8,7 @@ from .repo_data import RepoData
 from .simple_task import SimpleTask
 from .source import Source
 from .task import Task
-from .utils import Repr
+from .repr import Repr
 from .logger import Logger
 from .hypergol_project import HypergolProject
 # This spicy hack allows not to load TF each time we run CLI command which of course doesn't use TF - Laszlo
