@@ -1,6 +1,7 @@
 # pylint: disable=E0611, W0235
 
 import inspect
+
 from tensorflow.python.keras import layers
 
 
@@ -12,9 +13,10 @@ class BaseTensorflowModelBlock(layers.Layer):
         There is no delayed initialisation in Hypergol models.
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, blockName=None, **kwargs):
         """If further keras layers are required, they should be created here"""
         super(BaseTensorflowModelBlock, self).__init__(*args, **kwargs)
+        self.blockName = blockName or self.__class__.__name__
 
     def get_config(self):
         """Function to get the configuration parameters for serialisation"""
@@ -25,9 +27,6 @@ class BaseTensorflowModelBlock(layers.Layer):
                 config[name] = value
         return config
 
-    def get_name(self):
-        return self.__class__.__name__
-
     def build(self, input_shape):
         """This should not be called"""
         raise Exception(f'keras.Layer.build() was called in Hypergol block {self.__class__.__name__}')
